local ui = require('ui')
http = require("socket.http")
ltn12 = require("ltn12")
url = require("socket.url")
require("Json")

local appname = "APPNAME"
display.setStatusBar( display.HiddenStatusBar )
system.setLocationAccuracy( 10 )

local isSimulator = "simulator" == system.getInfo("environment")
local deviceId = system.getInfo("deviceID")

local bg = display.newRect(0, 0, display.contentWidth, display.contentHeight)

local logo = display.newImageRect("logo.png", 172, 107)
logo.x = display.contentWidth / 2
logo.y = (display.contentHeight / 2) - 150

local titleLabel = ui.newLabel{
        bounds = { 15, 5, 290, 55 },
        text = "Message",
        font = native.systemFontBold,
        textColor = { 12, 12, 100, 255 },
        size = 24,
        align = "center"
}
titleLabel:setReferencePoint(display.TopCenterReferencePoint)
titleLabel.y = logo.y + 60


if isSimulator then
	-- Simulator (simulate the textField area)
	textField = display.newRect( 20, titleLabel.y + 60, 280, 30 )
	textField:setFillColor( 200, 200, 200 )
else
	local function fieldHandler( event )
		if ( "submitted" == event.phase ) then
			native.setKeyboardFocus( nil )
		end
	end
    textField = native.newTextField( 20, titleLabel.y + 60, 280, 30, fieldHandler )
end             

textField:setReferencePoint(display.TopCenterReferencePoint)
textField.x = display.contentWidth / 2
textField.y = titleLabel.y + 60

local removeKeyboard = function( event )
        -- Hide keyboard
        native.setKeyboardFocus( nil )
end
bg:addEventListener( "tap", removeKeyboard )


local latitudeText = ""
local longitudeText = ""
if isSimulator then
	local alert = native.showAlert( "Error", "GPS not available in Simulator" )
else
 	local locationHandler = function(event)
		latitudeText = string.format( '%.8f', event.latitude )
		longitudeText = string.format( '%.8f', event.longitude )
	end
	Runtime:addEventListener( "location", locationHandler )
end

local getThump = function(event)
	if event.isShake == true then
		system.vibrate()
		local message = textField.text
		local post = "thump[deviceid]="..deviceId.."&thump[lat]="..latitudeText.."&thump[lng]="..longitudeText.."&thump[message]="..message
		
		--FOR TESTING
		--local post = "thump[deviceid]="..deviceId.."&thump[lat]=".."40.7141667".."&thump[lng]=".."-74.0063889".."&thump[message]=".."message"
		
		local response = {}

		local r, c, h = http.request {
		    url = "http://"..appname..".heroku.com/thumps",
		    method = "POST",
		    headers = {
		        ["content-length"] = #post,
		        ["Content-Type"] =  "application/x-www-form-urlencoded"
		    },
		    source = ltn12.source.string(post),
		    sink = ltn12.sink.table(response)
		}
		local jsonpost = Json.Decode(table.concat(response,''))
		
		local function showError()
			local alert = native.showAlert( "Error!", "Please try your thump again!", {"OK"} )
		end
		
		if(jsonpost.success == true) then
			native.setActivityIndicator( true );
		
			local attempts = 0
			function retrieveThump( event )
					print (attempts)
			        if 10 == attempts then
			        	native.setActivityIndicator( false );
						timer.cancel( event.source )
						showError()
					else
						local response = {}
						local r, c, h = http.request {
						    url = "http://"..appname..".heroku.com/thumps/search?thump[deviceid]="..deviceId.."&thump[lat]="..latitudeText.."&thump[lng]="..longitudeText,
						    method = "GET",
						    sink = ltn12.sink.table(response)
						}
						local jsonget = Json.Decode(table.concat(response,''))
						if(jsonget.success == true) then
							native.setActivityIndicator( false );
							timer.cancel( event.source )
							local alert = native.showAlert( "Thump!", jsonget.message, {"OK"} )
						end
						attempts = attempts + 1
						timer.performWithDelay( 3000, retrieveThump)
			        end
			end
			timer.performWithDelay( 1000, retrieveThump)
		else
			showError()
		end
		
	end
end
Runtime:addEventListener("accelerometer", getThump)
